@@ -20,8 +20,6 @@ all
 <screenshot>none</screenshot>
 
 <preinstall>
-echo "---- in preprocessing ----"
-echo "---- preprocessing done----"
 </preinstall>
 
 <install_package_names>
