@@ -20,8 +20,6 @@ all
 <screenshot>none</screenshot>
 
 <preinstall>
-echo "---- in preprocessing ----"
-echo "---- preprocessing done----"
 </preinstall>
 
 <install_package_names>
@@ -31,7 +29,7 @@ libreoffice-impress
 libreoffice-math
 libreoffice-writer
 libreoffice-l10n-nn
-libreoffice-gtk
+libreoffice-gtk2
 </install_package_names>
 
 <postinstall>
@@ -45,7 +43,7 @@ libreoffice-impress
 libreoffice-math
 libreoffice-writer
 libreoffice-l10n-nn
-libreoffice-gtk
+libreoffice-gtk2
 </uninstall_package_names>
 
 </app>
