@@ -17,7 +17,7 @@ Kodi Media Center (formerly XBMC)
 all
 </installable>
 
-<screenshot>https://screenshots.debian.net/screenshots/000/013/655/large.png</screenshot>
+<screenshot>none</screenshot>
 
 <preinstall>
 
