@@ -17,7 +17,7 @@ search and download Youtube videos
 all
 </installable>
 
-<screenshot>https://screenshots.debian.net/screenshots/000/010/334/large.png</screenshot>
+<screenshot>none</screenshot>
 
 <preinstall>
 
